@@ -4,10 +4,12 @@ Using Redis in TorCMS.
 '''
 import redis
 
-redisvr = redis.Redis(host='localhost',
-                      port=6379,
+from config import REDIS_CFG
+
+redisvr = redis.Redis(host=REDIS_CFG.get('host'),
+                      port=REDIS_CFG.get('port'),
                       db=0,
-                      password=None,
+                      password=REDIS_CFG.get('pass'),
                       socket_timeout=None,
                       connection_pool=None,
                       charset='utf-8',
