@@ -3,6 +3,7 @@
 Admin
 '''
 import tornado.web
+
 import config
 from torcms.core.base_handler import BaseHandler
 
@@ -11,18 +12,15 @@ class AdminHandler(BaseHandler):
     '''
     Handler for Admin.
     '''
-
     def initialize(self, **kwargs):
-        super(AdminHandler, self).initialize()
+        super().initialize()
 
     def get(self, *args, **kwargs):
         url_str = args[0]
         if url_str == '':
             self.index()
         else:
-            self.render('misc/html/404.html',
-                        kwd={},
-                        userinfo=self.userinfo)
+            self.render('misc/html/404.html', kwd={}, userinfo=self.userinfo)
 
     @tornado.web.authenticated
     def index(self):
