@@ -1,5 +1,4 @@
 # -*- coding:utf-8 -*-
-
 '''
 For catalog hander.
 '''
@@ -11,8 +10,7 @@ class CatalogHandler(ListHandler):
     '''
     For catalog hander.
     '''
-
     def initialize(self, **kwargs):
-        super(CatalogHandler, self).initialize()
+        super().initialize()
         self.kind = kwargs.get('kind', '1')
         self.order = True
