@@ -1,12 +1,13 @@
 # -*- coding:utf-8 -*-
-
 '''
 For the evaluation of the posts.
 '''
 import json
+
 import tornado.web
-from torcms.model.evaluation_model import MEvaluation
+
 from torcms.core.base_handler import BaseHandler
+from torcms.model.evaluation_model import MEvaluation
 
 
 class EvaluationHandler(BaseHandler):
@@ -15,7 +16,7 @@ class EvaluationHandler(BaseHandler):
     '''
 
     def initialize(self, **kwargs):
-        super(EvaluationHandler, self).initialize()
+        super().initialize()
 
     def get(self, *args, **kwargs):
         url_arr = self.parse_url(args[0])
