@@ -1,10 +1,10 @@
 # -*- coding:utf-8 -*-
-
 '''
 All other static pages.
 '''
 
 import os
+
 from torcms.core.base_handler import BaseHandler
 
 
@@ -12,9 +12,8 @@ class StaticHandler(BaseHandler):
     '''
     All other static pages.
     '''
-
     def initialize(self):
-        super(StaticHandler, self).initialize()
+        super().initialize()
 
     def get(self, *args, **kwargs):
         url_str = args[0]
@@ -22,12 +21,12 @@ class StaticHandler(BaseHandler):
             'pager': '',
         }
         static_html_file = 'templates/static_pages/{0}'.format(url_str)
-        if os.path.exists(static_html_file) and os.path.isfile(static_html_file):
+        if os.path.exists(static_html_file) and os.path.isfile(
+                static_html_file):
             kwd['info'] = ''
             self.render('static_pages/{0}'.format(url_str),
                         kwd=kwd,
                         userinfo=self.userinfo)
         else:
             kwd['info'] = '404! Page not found.'
-            self.render('misc/html/404.html', kwd=kwd,
-                        userinfo=self.userinfo)
+            self.render('misc/html/404.html', kwd=kwd, userinfo=self.userinfo)
