@@ -1,5 +1,4 @@
 # -*- coding:utf-8 -*-
-
 '''
 The Base of Model
 '''
@@ -11,7 +10,6 @@ class MHelper():
     '''
     Common used function for most Model. Using Model as the first parameter.
     '''
-
     @staticmethod
     def get_by_uid(model, uid):
         recs = model.select().where(model.uid == uid)
@@ -26,5 +24,6 @@ class MHelper():
         try:
             entry.execute()
             return True
-        except:
+        except Exception as err:
+            print(repr(err))
             return False
