@@ -1,23 +1,19 @@
 # -*- coding:utf-8 -*-
-
 '''
 Model for Posts.
 '''
 
-from torcms.model.core_tab import TabPost, TabTag
-from torcms.model.core_tab import TabPost2Tag
-
 from torcms.model.abc_model import Mabc
 from torcms.model.category_model import MCategory
+from torcms.model.core_tab import TabPost, TabPost2Tag, TabTag
 
 
 class MCatalog(Mabc):
     '''
     Model for catalog list.
     '''
-
     def __init__(self):
-        super(MCatalog, self).__init__()
+        super().__init__()
 
     @staticmethod
     def query_by_slug(slug):
@@ -37,12 +33,8 @@ class MCatalog(Mabc):
 
         recs = TabPost.select().join(
             TabPost2Tag,
-            on=(TabPost.uid == TabPost2Tag.post_id)
-        ).where(
-            cat_con
-        ).order_by(
-            TabPost.time_update.desc()
-        )
+            on=(TabPost.uid == TabPost2Tag.post_id)).where(cat_con).order_by(
+                TabPost.time_update.desc())
 
         return recs
 
@@ -52,5 +44,6 @@ class MCatalog(Mabc):
         查询大类记录
         '''
 
-        recs = TabTag.select().where(TabTag.uid.endswith('00')).order_by(TabTag.uid)
+        recs = TabTag.select().where(TabTag.uid.endswith('00')).order_by(
+            TabTag.uid)
         return recs
