@@ -1,20 +1,19 @@
 # -*- coding:utf-8 -*-
-
 '''
 Model for Posts.
 '''
 import time
 from datetime import datetime
+
 import peewee
 import tornado.escape
-from torcms.core import tools
-from torcms.model.core_tab import TabPost
-from torcms.model.core_tab import TabPost2Tag
-from torcms.model.core_tab import TabPostHist, TabCollect, TabRel, TabEvaluation, TabReply, \
-    TabRating, TabUsage, \
-    TabUser2Reply
-from torcms.model.abc_model import Mabc, MHelper
+
 from config import CMS_CFG, DB_CFG
+from torcms.core import tools
+from torcms.model.abc_model import Mabc, MHelper
+from torcms.model.core_tab import (TabCollect, TabEvaluation, TabPost,
+                                   TabPost2Tag, TabPostHist, TabRating, TabRel,
+                                   TabReply, TabUsage, TabUser2Reply)
 
 
 class MPost(Mabc):
@@ -30,12 +29,9 @@ class MPost(Mabc):
         :param recent: the number of days recent.
         '''
         time_that = int(time.time()) - recent * 24 * 3600
-        return TabPost.select().where(
-            (TabPost.time_update > time_that) &
-            (TabPost.valid == 1)
-        ).order_by(
-            TabPost.view_count.desc()
-        ).limit(num)
+        return TabPost.select().where((TabPost.time_update > time_that)
+                                      & (TabPost.valid == 1)).order_by(
+            TabPost.view_count.desc()).limit(num)
 
     @staticmethod
     def delete(uid):
@@ -45,7 +41,8 @@ class MPost(Mabc):
 
         q_u1 = TabPostHist.delete().where(TabPostHist.post_id == uid)
         q_u1.execute()
-        q_u2 = TabRel.delete().where(TabRel.post_f_id == uid or TabRel.post_t_id == uid)
+        q_u2 = TabRel.delete().where(TabRel.post_f_id == uid
+                                     or TabRel.post_t_id == uid)
         q_u2.execute()
         q_u3 = TabCollect.delete().where(TabCollect.post_id == uid)
         q_u3.execute()
@@ -55,7 +52,8 @@ class MPost(Mabc):
         q_u5.execute()
 
         reply_arr = []
-        for reply in TabUser2Reply.select().where(TabUser2Reply.reply_id == uid):
+        for reply in TabUser2Reply.select().where(
+                TabUser2Reply.reply_id == uid):
             reply_arr.append(reply.reply_id.uid)
 
         q_u6 = TabUser2Reply.delete().where(TabUser2Reply.reply_id == uid)
@@ -90,9 +88,7 @@ class MPost(Mabc):
         '''
         Update the rating for post.
         '''
-        entry = TabPost.update(
-            rating=rating
-        ).where(TabPost.uid == uid)
+        entry = TabPost.update(rating=rating).where(TabPost.uid == uid)
         entry.execute()
 
     @staticmethod
@@ -101,18 +97,14 @@ class MPost(Mabc):
         update the kind of post.
         '''
 
-        entry = TabPost.update(
-            kind=kind,
-        ).where(TabPost.uid == uid)
+        entry = TabPost.update(kind=kind, ).where(TabPost.uid == uid)
         entry.execute()
         return True
 
     @staticmethod
     def update_field(uid, post_id=None):
         if post_id:
-            entry = TabPost.update(
-                uid=post_id
-            ).where(TabPost.uid == uid)
+            entry = TabPost.update(uid=post_id).where(TabPost.uid == uid)
             entry.execute()
 
     @staticmethod
@@ -125,8 +117,7 @@ class MPost(Mabc):
             cnt_html=tools.markdown2html(post_data['cnt_md']),
             user_name=post_data['user_name'],
             cnt_md=tornado.escape.xhtml_escape(post_data['cnt_md'].strip()),
-            time_update=tools.timestamp()
-        ).where(TabPost.uid == uid)
+            time_update=tools.timestamp()).where(TabPost.uid == uid)
         entry.execute()
 
     @staticmethod
@@ -134,56 +125,72 @@ class MPost(Mabc):
         '''
         Update the order of the posts.
         '''
-        entry = TabPost.update(
-            order=order
-        ).where(TabPost.uid == uid)
+        entry = TabPost.update(order=order).where(TabPost.uid == uid)
         entry.execute()
 
     @staticmethod
-    def update(uid, post_data, update_time=False):
+    def update(uid, post_data, update_time=True):
         '''
-        update the infor.
+        参数 `update_time` ， 是否更新时间。对于导入的数据，有时不需要更新。
         '''
 
         title = post_data['title'].strip()
         if len(title) < 2:
             return False
         cnt_html = tools.markdown2html(post_data['cnt_md'])
-        try:
-            if update_time:
-                entry2 = TabPost.update(
-                    date=datetime.now(),
-                    time_create=tools.timestamp()
-                ).where(TabPost.uid == uid)
-                entry2.execute()
-        except:
-            pass
+        # try:
+        #     if update_time:
+        #         entry2 = TabPost.update(
+        #             date=datetime.now(),
+        #             time_create=tools.timestamp()
+        #         ).where(TabPost.uid == uid)
+        #         entry2.execute()
+        # except:
+        #     pass
         cur_rec = MPost.get_by_uid(uid)
 
-        entry = TabPost.update(
-            title=title,
-            user_name=post_data['user_name'],
-            cnt_md=tornado.escape.xhtml_escape(post_data['cnt_md'].strip()),
-            memo=post_data['memo'] if 'memo' in post_data else '',
-            cnt_html=cnt_html,
-            logo=post_data['logo'],
-            order=post_data['order'] if 'order' in post_data else '',
-            keywords=post_data['keywords'] if 'keywords' in post_data else '',
-            kind=post_data['kind'] if 'kind' in post_data else 1,
-            extinfo=post_data['extinfo'] if 'extinfo' in post_data else cur_rec.extinfo,
-            time_update=tools.timestamp(),
-            valid=post_data.get('valid', 1)
-        ).where(TabPost.uid == uid)
+        if update_time:
+            entry = TabPost.update(
+                title=title,
+                user_name=post_data['user_name'],
+                cnt_md=tornado.escape.xhtml_escape(
+                    post_data['cnt_md'].strip()),
+                memo=post_data['memo'] if 'memo' in post_data else '',
+                cnt_html=cnt_html,
+                logo=post_data['logo'],
+                order=post_data['order'] if 'order' in post_data else '',
+                keywords=post_data['keywords']
+                if 'keywords' in post_data else '',
+                kind=post_data['kind'] if 'kind' in post_data else 1,
+                extinfo=post_data['extinfo']
+                if 'extinfo' in post_data else cur_rec.extinfo,
+                time_update=tools.timestamp(),
+                valid=post_data.get('valid', 1)).where(TabPost.uid == uid)
+        else:
+            entry = TabPost.update(
+                title=title,
+                user_name=post_data['user_name'],
+                cnt_md=tornado.escape.xhtml_escape(
+                    post_data['cnt_md'].strip()),
+                memo=post_data['memo'] if 'memo' in post_data else '',
+                cnt_html=cnt_html,
+                logo=post_data['logo'],
+                order=post_data['order'] if 'order' in post_data else '',
+                keywords=post_data['keywords'] if 'keywords' in post_data else '',
+                kind=post_data['kind'] if 'kind' in post_data else 1,
+                extinfo=post_data['extinfo']
+                if 'extinfo' in post_data else cur_rec.extinfo,
+                valid=post_data.get('valid', 1)).where(TabPost.uid == uid)
         entry.execute()
 
     @staticmethod
-    def add_or_update(uid, post_data):
+    def add_or_update(uid, post_data, update_time=True):
         '''
         Add or update the post.
         '''
         cur_rec = MPost.get_by_uid(uid)
         if cur_rec:
-            MPost.update(uid, post_data)
+            MPost.update(uid, post_data, update_time=update_time)
         else:
             MPost.create_post(uid, post_data)
 
@@ -209,15 +216,15 @@ class MPost(Mabc):
             time_create=post_data.get('time_create', tools.timestamp()),
             time_update=post_data.get('time_update', tools.timestamp()),
             user_name=post_data['user_name'],
-            view_count=post_data['view_count'] if 'view_count' in post_data else 1,
+            view_count=post_data['view_count']
+            if 'view_count' in post_data else 1,
             logo=post_data['logo'],
             memo=post_data['memo'] if 'memo' in post_data else '',
             order=post_data['order'] if 'order' in post_data else '',
             keywords=post_data['keywords'] if 'keywords' in post_data else '',
             extinfo=post_data['extinfo'] if 'extinfo' in post_data else {},
             kind=post_data['kind'] if 'kind' in post_data else '1',
-            valid=post_data.get('valid', 1)
-        )
+            valid=post_data.get('valid', 1))
         return entry.uid
 
     @staticmethod
@@ -227,17 +234,15 @@ class MPost(Mabc):
         '''
         num = kwargs.get('limit', 8)
         if catid == '':
-            rand_recs = TabPost.select().where(TabPost.valid == 1).order_by(peewee.fn.Random()).limit(num)
+            rand_recs = TabPost.select().where(TabPost.valid == 1).order_by(
+                peewee.fn.Random()).limit(num)
         else:
             rand_recs = TabPost.select().join(
                 TabPost2Tag,
-                on=(TabPost.uid == TabPost2Tag.post_id)
-            ).where(
-                (TabPost.valid == 1) &
-                (TabPost2Tag.tag_id == catid)
-            ).order_by(
-                peewee.fn.Random()
-            ).limit(num)
+                on=(TabPost.uid == TabPost2Tag.post_id
+                    )).where((TabPost.valid == 1)
+                             & (TabPost2Tag.tag_id == catid)).order_by(
+                peewee.fn.Random()).limit(num)
         return rand_recs
 
     @staticmethod
@@ -256,18 +261,11 @@ class MPost(Mabc):
         kind = kwargs.get('kind', None)
 
         if kind:
-            rand_recs = TabPost.select().where(
-                (TabPost.kind == kind) &
-                (TabPost.valid == 1)
-            ).order_by(
-                peewee.fn.Random()
-            ).limit(limit)
+            rand_recs = TabPost.select().where((TabPost.kind == kind) & (
+                    TabPost.valid == 1)).order_by(peewee.fn.Random()).limit(limit)
         else:
-            rand_recs = TabPost.select().where(
-                TabPost.valid == 1
-            ).order_by(
-                peewee.fn.Random()
-            ).limit(limit)
+            rand_recs = TabPost.select().where(TabPost.valid == 1).order_by(
+                peewee.fn.Random()).limit(limit)
         return rand_recs
 
     @staticmethod
@@ -280,31 +278,21 @@ class MPost(Mabc):
         if order_by_create:
             if kind:
                 recent_recs = TabPost.select().where(
-                    (TabPost.kind == kind) &
-                    (TabPost.valid == 1)
-                ).order_by(
-                    TabPost.time_create.desc()
-                ).limit(num)
+                    (TabPost.kind == kind) & (TabPost.valid == 1)).order_by(
+                    TabPost.time_create.desc()).limit(num)
             else:
                 recent_recs = TabPost.select().where(
-                    TabPost.valid == 1
-                ).order_by(
-                    TabPost.time_create.desc()
-                ).limit(num)
+                    TabPost.valid == 1).order_by(
+                    TabPost.time_create.desc()).limit(num)
         else:
             if kind:
                 recent_recs = TabPost.select().where(
-                    (TabPost.kind == kind) &
-                    (TabPost.valid == 1)
-                ).order_by(
-                    TabPost.time_update.desc()
-                ).limit(num)
+                    (TabPost.kind == kind) & (TabPost.valid == 1)).order_by(
+                    TabPost.time_update.desc()).limit(num)
             else:
                 recent_recs = TabPost.select().where(
-                    TabPost.valid == 1
-                ).order_by(
-                    TabPost.time_update.desc()
-                ).limit(num)
+                    TabPost.valid == 1).order_by(
+                    TabPost.time_update.desc()).limit(num)
         return recent_recs
 
     @staticmethod
@@ -316,56 +304,44 @@ class MPost(Mabc):
         limit = kwargs.get('limit', 10)
 
         return TabPost.select().where(
-            (TabPost.kind == kind) &
-            (TabPost.valid == 1)
-        ).order_by(
-            TabPost.time_update.desc()
-        ).limit(limit)
+            (TabPost.kind == kind) & (TabPost.valid == 1)).order_by(
+            TabPost.time_update.desc()).limit(limit)
 
     @staticmethod
     def query_keywords_empty(kind='1'):
         '''
         Query keywords, empty.
         '''
-        return TabPost.select().where(
-            (TabPost.kind == kind) &
-            (TabPost.keywords == '')
-        )
+        return TabPost.select().where((TabPost.kind == kind)
+                                      & (TabPost.keywords == ''))
 
     @staticmethod
     def query_recent_edited(timstamp, kind='1'):
         '''
         获取最近更新的Post，以时间戳为条件
         '''
-        return TabPost.select().where(
-            (TabPost.kind == kind) &
-            (TabPost.time_update > timstamp)
-        ).order_by(
-            TabPost.time_update.desc()
-        )
+        return TabPost.select().where((TabPost.kind == kind) & (
+                TabPost.time_update > timstamp)).order_by(
+            TabPost.time_update.desc())
 
     @staticmethod
     def query_dated(num=8, kind='1'):
         '''
         获取久未更新的Post列表。
         '''
-        return TabPost.select().where(
-            (TabPost.kind == kind) &
-            (TabPost.valid == 1)
-        ).order_by(
-            TabPost.time_update.asc()
-        ).limit(num)
+        return TabPost.select().where((TabPost.kind == kind)
+                                      & (TabPost.valid == 1)).order_by(
+            TabPost.time_update.asc()).limit(num)
 
     @staticmethod
     def query_most_pic(num, kind='1'):
         '''
         Query most pics.
         '''
-        return TabPost.select().where(
-            (TabPost.kind == kind) &
-            (TabPost.logo != "") &
-            (TabPost.valid == 1)
-        ).order_by(TabPost.view_count.desc()).limit(num)
+        return TabPost.select().where((TabPost.kind == kind)
+                                      & (TabPost.logo != "")
+                                      & (TabPost.valid == 1)).order_by(
+            TabPost.view_count.desc()).limit(num)
 
     @staticmethod
     def query_cat_recent(cat_id, label=None, num=8, kind='1', order=False):
@@ -374,20 +350,16 @@ class MPost(Mabc):
         '''
 
         if label:
-            recent_recs = MPost.query_cat_recent_with_label(
-                cat_id,
-                label=label,
-                num=num,
-                kind=kind,
-                order=order
-            )
+            recent_recs = MPost.query_cat_recent_with_label(cat_id,
+                                                            label=label,
+                                                            num=num,
+                                                            kind=kind,
+                                                            order=order)
         else:
-            recent_recs = MPost.query_cat_recent_no_label(
-                cat_id,
-                num=num,
-                kind=kind,
-                order=order
-            )
+            recent_recs = MPost.query_cat_recent_no_label(cat_id,
+                                                          num=num,
+                                                          kind=kind,
+                                                          order=order)
         return recent_recs
 
     @staticmethod
@@ -398,15 +370,11 @@ class MPost(Mabc):
         '''
 
         return TabPost.select().join(
-            TabPost2Tag,
-            on=(TabPost.uid == TabPost2Tag.post_id)
-        ).where(
-            (TabPost.kind == kind) &
-            (TabPost2Tag.tag_id == cat_id) &
-            (TabPost.valid == 1)
-        ).order_by(
-            TabPost.time_create.desc()
-        )
+            TabPost2Tag, on=(TabPost.uid == TabPost2Tag.post_id
+                             )).where((TabPost.kind == kind)
+                                      & (TabPost2Tag.tag_id == cat_id)
+                                      & (TabPost.valid == 1)).order_by(
+            TabPost.time_create.desc())
 
     @staticmethod
     def query_by_parid(par_id, kind='9'):
@@ -415,18 +383,18 @@ class MPost(Mabc):
 
         '''
         return TabPost.select().join(
-            TabPost2Tag,
-            on=(TabPost.uid == TabPost2Tag.post_id)
-        ).where(
-            (TabPost.kind == kind) &
-            (TabPost2Tag.par_id == par_id) &
-            (TabPost.valid == 1)
-        ).order_by(
-            TabPost.time_create.desc()
-        )
+            TabPost2Tag, on=(TabPost.uid == TabPost2Tag.post_id
+                             )).where((TabPost.kind == kind)
+                                      & (TabPost2Tag.par_id == par_id)
+                                      & (TabPost.valid == 1)).order_by(
+            TabPost.time_create.desc())
 
     @staticmethod
-    def query_cat_recent_with_label(cat_id, label=None, num=8, kind='1', order=False):
+    def query_cat_recent_with_label(cat_id,
+                                    label=None,
+                                    num=8,
+                                    kind='1',
+                                    order=False):
         '''
         query_cat_recent_with_label
         '''
@@ -436,16 +404,11 @@ class MPost(Mabc):
             sort_criteria = TabPost.time_create.desc()
 
         return TabPost.select().join(
-            TabPost2Tag,
-            on=(TabPost.uid == TabPost2Tag.post_id)
-        ).where(
-            (TabPost.kind == kind) &
-            (TabPost2Tag.tag_id == cat_id) &
-            (TabPost.valid == 1) &
-            (TabPost.extinfo['def_tag_arr'].contains(label))
-        ).order_by(
-            sort_criteria
-        ).limit(num)
+            TabPost2Tag, on=(TabPost.uid == TabPost2Tag.post_id)).where(
+            (TabPost.kind == kind) & (TabPost2Tag.tag_id == cat_id)
+            & (TabPost.valid == 1)
+            & (TabPost.extinfo['def_tag_arr'].contains(label))).order_by(
+            sort_criteria).limit(num)
 
     @staticmethod
     def query_cat_recent_no_label(cat_id, num=8, kind='1', order=False):
@@ -458,15 +421,9 @@ class MPost(Mabc):
             sort_criteria = TabPost.time_create.desc()
 
         return TabPost.select().join(
-            TabPost2Tag,
-            on=(TabPost.uid == TabPost2Tag.post_id)
-        ).where(
-            (TabPost.kind == kind) &
-            (TabPost2Tag.tag_id == cat_id) &
-            (TabPost.valid == 1)
-        ).order_by(
-            sort_criteria
-        ).limit(num)
+            TabPost2Tag, on=(TabPost.uid == TabPost2Tag.post_id)).where(
+            (TabPost.kind == kind) & (TabPost2Tag.tag_id == cat_id)
+            & (TabPost.valid == 1)).order_by(sort_criteria).limit(num)
 
     @staticmethod
     def query_total_cat_recent(cat_id_arr, label=None, num=8, kind='1'):
@@ -475,13 +432,13 @@ class MPost(Mabc):
         :param label: the additional label
         '''
         if label:
-            return MPost.__query_with_label(
-                cat_id_arr,
-                label=label,
-                num=num,
-                kind=kind
-            )
-        return MPost.query_total_cat_recent_no_label(cat_id_arr, num=num, kind=kind)
+            return MPost.__query_with_label(cat_id_arr,
+                                            label=label,
+                                            num=num,
+                                            kind=kind)
+        return MPost.query_total_cat_recent_no_label(cat_id_arr,
+                                                     num=num,
+                                                     kind=kind)
 
     @staticmethod
     def __query_with_label(cat_id_arr, label=None, num=8, kind='1'):
@@ -490,16 +447,13 @@ class MPost(Mabc):
         '''
         return TabPost.select().join(
             TabPost2Tag,
-            on=(TabPost.uid == TabPost2Tag.post_id)
-        ).where(
-            (TabPost.kind == kind) &
-            (TabPost2Tag.tag_id << cat_id_arr) &  # the "<<" operator signifies an "IN" query
-            (TabPost.extinfo['def_tag_arr'].contains(label) &
-             (TabPost.valid == 1)
-             )
-        ).order_by(
-            TabPost.time_create.desc()
-        ).limit(num)
+            on=(TabPost.uid == TabPost2Tag.post_id
+                )).where((TabPost.kind == kind)
+                         & (TabPost2Tag.tag_id << cat_id_arr)
+                         &  # the "<<" operator signifies an "IN" query
+                         (TabPost.extinfo['def_tag_arr'].contains(label)
+                          & (TabPost.valid == 1))).order_by(
+            TabPost.time_create.desc()).limit(num)
 
     @staticmethod
     def query_total_cat_recent_no_label(cat_id_arr, num=8, kind='1'):
@@ -508,26 +462,21 @@ class MPost(Mabc):
         '''
         return TabPost.select().join(
             TabPost2Tag,
-            on=(TabPost.uid == TabPost2Tag.post_id)
-        ).where(
-            (TabPost.kind == kind) &
-            (TabPost2Tag.tag_id << cat_id_arr) &  # the "<<" operator signifies an "IN" query
-            (TabPost.valid == 1)
-        ).order_by(
-            TabPost.time_create.desc()
-        ).limit(num)
+            on=(TabPost.uid == TabPost2Tag.post_id
+                )).where((TabPost.kind == kind)
+                         & (TabPost2Tag.tag_id << cat_id_arr)
+                         &  # the "<<" operator signifies an "IN" query
+                         (TabPost.valid == 1)).order_by(
+            TabPost.time_create.desc()).limit(num)
 
     @staticmethod
     def query_most(num=8, kind='1'):
         '''
         Query most viewed.
         '''
-        return TabPost.select().where(
-            (TabPost.kind == kind) &
-            (TabPost.valid == 1)
-        ).order_by(
-            TabPost.view_count.desc()
-        ).limit(num)
+        return TabPost.select().where((TabPost.kind == kind)
+                                      & (TabPost.valid == 1)).order_by(
+            TabPost.view_count.desc()).limit(num)
 
     @staticmethod
     def update_misc(uid, **kwargs):
@@ -547,11 +496,14 @@ class MPost(Mabc):
     def __update_view_count(uid):
         '''
         '''
-        entry = TabPost.update(view_count=TabPost.view_count + 1).where(TabPost.uid == uid)
+        entry = TabPost.update(
+            view_count=TabPost.view_count + 1
+        ).where(TabPost.uid == uid)
         try:
             entry.execute()
             return True
-        except:
+        except Exception as err:
+            print(repr(err))
             return False
 
     @staticmethod
@@ -569,10 +521,9 @@ class MPost(Mabc):
         '''
         current_rec = MPost.get_by_uid(in_uid)
         recs = TabPost.select().where(
-            (TabPost.kind == kind) &
-            (TabPost.time_create < current_rec.time_create) &
-            (TabPost.valid == 1)
-        ).order_by(TabPost.time_create.desc())
+            (TabPost.kind == kind)
+            & (TabPost.time_create < current_rec.time_create)
+            & (TabPost.valid == 1)).order_by(TabPost.time_create.desc())
         if recs.count():
             return recs.get()
         return None
@@ -584,10 +535,9 @@ class MPost(Mabc):
         '''
         current_rec = MPost.get_by_uid(in_uid)
         recs = TabPost.select().where(
-            (TabPost.kind == kind) &
-            (TabPost.time_create > current_rec.time_create) &
-            (TabPost.valid == 1)
-        ).order_by(TabPost.time_create)
+            (TabPost.kind == kind)
+            & (TabPost.time_create > current_rec.time_create)
+            & (TabPost.valid == 1)).order_by(TabPost.time_create)
         if recs.count():
             return recs.get()
         return None
@@ -597,12 +547,9 @@ class MPost(Mabc):
         '''
         Get All the records.
         '''
-        return TabPost.select().where(
-            (TabPost.kind == kind) &
-            (TabPost.valid == 1)
-        ).order_by(
-            TabPost.time_update.desc()
-        )
+        return TabPost.select().where((TabPost.kind == kind)
+                                      & (TabPost.valid == 1)).order_by(
+            TabPost.time_update.desc())
 
     @staticmethod
     def update_jsonb(uid, extinfo):
@@ -612,9 +559,7 @@ class MPost(Mabc):
         cur_extinfo = MPost.get_by_uid(uid).extinfo
         for key in extinfo:
             cur_extinfo[key] = extinfo[key]
-        entry = TabPost.update(
-            extinfo=cur_extinfo,
-        ).where(TabPost.uid == uid)
+        entry = TabPost.update(extinfo=cur_extinfo, ).where(TabPost.uid == uid)
         entry.execute()
         return uid
 
@@ -649,8 +594,7 @@ class MPost(Mabc):
                 order=data_dic['order'] if 'order' in data_dic else '',
                 cnt_html=tools.markdown2html(data_dic['cnt_md']),
                 extinfo=cur_extinfo,
-                valid=data_dic['valid']
-            ).where(TabPost.uid == uid)
+                valid=data_dic['valid']).where(TabPost.uid == uid)
             entry.execute()
         else:
             return MPost.add_meta(uid, data_dic, extinfo)
@@ -666,12 +610,12 @@ class MPost(Mabc):
             time_update=tools.timestamp(),
             date=datetime.now(),
             kind=data_dic['kind'] if 'kind' in data_dic else postinfo.kind,
-            keywords=data_dic['keywords'] if 'keywords' in data_dic else postinfo.keywords,
+            keywords=data_dic['keywords']
+            if 'keywords' in data_dic else postinfo.keywords,
         ).where(TabPost.uid == uid)
         entry.execute()
         return uid
 
-
     @staticmethod
     def query_most_by_cat(num=8, catid=None, kind='2'):
         '''
@@ -680,14 +624,10 @@ class MPost(Mabc):
         if catid:
             return TabPost.select().join(
                 TabPost2Tag,
-                on=(TabPost.uid == TabPost2Tag.post_id)
-            ).where(
-                (TabPost.kind == kind) &
-                (TabPost.valid == 1) &
-                (TabPost2Tag.tag_id == catid)
-            ).order_by(
-                TabPost.view_count.desc()
-            ).limit(num)
+                on=(TabPost.uid == TabPost2Tag.post_id
+                    )).where((TabPost.kind == kind) & (TabPost.valid == 1)
+                             & (TabPost2Tag.tag_id == catid)).order_by(
+                TabPost.view_count.desc()).limit(num)
         return False
 
     @staticmethod
@@ -697,37 +637,26 @@ class MPost(Mabc):
         '''
         return TabPost.select().join(
             TabPost2Tag,
-            on=(TabPost.uid == TabPost2Tag.post_id)
-        ).where(
-            (TabPost.kind == kind) &
-            (TabPost.valid == 1) &
-            (TabPost2Tag.tag_id == cat_str)
-        ).order_by(
-            TabPost.view_count
-        ).limit(num)
+            on=(TabPost.uid == TabPost2Tag.post_id
+                )).where((TabPost.kind == kind) & (TabPost.valid == 1)
+                         & (TabPost2Tag.tag_id == cat_str)).order_by(
+            TabPost.view_count).limit(num)
 
     @staticmethod
     def get_by_keyword(par2, kind='2'):
         '''
         根据关键字对标题进行检索
         '''
-        return TabPost.select().where(
-            (TabPost.kind == kind) &
-            (TabPost.valid == 1) &
-            (TabPost.title.contains(par2))
-        ).order_by(
-            TabPost.time_update.desc()
-        ).limit(20)
+        return TabPost.select().where((TabPost.kind == kind) & (
+                TabPost.valid == 1) & (TabPost.title.contains(par2))).order_by(
+            TabPost.time_update.desc()).limit(20)
 
     @staticmethod
     def query_extinfo_by_cat(cat_id, kind='2'):
         return TabPost.select().where(
-            (TabPost.kind == kind) &
-            (TabPost.valid == 1) &
-            (TabPost.extinfo['def_cat_uid'] == cat_id)
-        ).order_by(
-            TabPost.time_update.desc()
-        )
+            (TabPost.kind == kind) & (TabPost.valid == 1)
+            & (TabPost.extinfo['def_cat_uid'] == cat_id)).order_by(
+            TabPost.time_update.desc())
 
     @staticmethod
     def query_by_extinfo(key='', val=''):
@@ -735,10 +664,7 @@ class MPost(Mabc):
         根据扩展字段查询
         '''
         return TabPost.select().where(
-            (TabPost.extinfo[key] == val)
-        ).order_by(
-            TabPost.time_update.desc()
-        )
+            (TabPost.extinfo[key] == val)).order_by(TabPost.time_update.desc())
 
     @staticmethod
     def query_by_tagname(tag_name, kind='2'):
@@ -746,12 +672,9 @@ class MPost(Mabc):
         根据标签进行查询
         '''
         return TabPost.select().where(
-            (TabPost.kind == kind) &
-            (TabPost.valid == 1) &
-            (TabPost.extinfo['def_tag_arr'].contains(tag_name))
-        ).order_by(
-            TabPost.time_update.desc()
-        )
+            (TabPost.kind == kind) & (TabPost.valid == 1)
+            & (TabPost.extinfo['def_tag_arr'].contains(tag_name))).order_by(
+            TabPost.time_update.desc())
 
     @staticmethod
     def get_label_fenye(tag_slug, _idx):
@@ -763,11 +686,9 @@ class MPost(Mabc):
 
     @staticmethod
     def query_pager_by_tag(tag, current_page_num=1, kind='2'):
-        recs = MPost.query_by_tagname(
-            tag, kind
-        ).paginate(
-            current_page_num, CMS_CFG['list_num']
-        )
+        recs = MPost.query_by_tagname(tag,
+                                      kind).paginate(current_page_num,
+                                                     CMS_CFG['list_num'])
         return recs
 
     @staticmethod
@@ -805,23 +726,34 @@ class MPost(Mabc):
         return uid
 
     @staticmethod
-    def query_under_condition(condition, kind='9'):
+    def query_under_condition(condition, kind='9', sort_option=''):
         '''
         Get All data of certain kind according to the condition
         '''
         if DB_CFG['kind'] == 's':
-            return TabPost.select().where(
-                (TabPost.kind == kind) &
-                (TabPost.valid == 1)
-            ).order_by(
-                TabPost.time_update.desc()
-            )
+            return TabPost.select().where((TabPost.kind == kind)
+                                          & (TabPost.valid == 1)).order_by(
+                TabPost.time_update.desc())
+
+        if sort_option:
+            if sort_option == 'time_update':
+                sort_criteria = TabPost.time_update.desc()
+            elif sort_option == 'time_create':
+                sort_criteria = TabPost.time_create.desc()
+            elif sort_option == 'access_1d':
+                sort_criteria = TabPost.access_1d.desc()
+            elif sort_option == 'access_7d':
+                sort_criteria = TabPost.access_7d.desc()
+            elif sort_option == 'access_30d':
+                sort_criteria = TabPost.access_30d.desc()
+            else:
+                sort_criteria = TabPost.view_count.desc()
+        else:
+            sort_criteria = TabPost.time_update.desc()
 
         return TabPost.select().where(
-            (TabPost.kind == kind) &
-            (TabPost.valid == 1) &
-            TabPost.extinfo.contains(condition)
-        ).order_by(TabPost.time_update.desc())
+            (TabPost.kind == kind) & (TabPost.valid == 1)
+            & TabPost.extinfo.contains(condition)).order_by(sort_criteria)
 
     @staticmethod
     def get_num_condition(con):
@@ -862,16 +794,20 @@ class MPost(Mabc):
                 date=datetime.now(),
                 keywords='',
                 view_count=0,
-                extinfo=ext_dic
-            )
+                extinfo=ext_dic)
 
     @staticmethod
-    def query_list_pager(con, idx, kind='2'):
+    def query_list_pager(con, idx, kind='2', sort_option=''):
         '''
         Get records of certain pager.
         '''
-        all_list = MPost.query_under_condition(con, kind=kind)
-        return all_list[(idx - 1) * CMS_CFG['list_num']: idx * CMS_CFG['list_num']]
+        if sort_option:
+            recs = MPost.query_under_condition(con,
+                                               kind=kind,
+                                               sort_option=sort_option)
+        else:
+            recs = MPost.query_under_condition(con, kind=kind)
+        return recs[(idx - 1) * CMS_CFG['list_num']:idx * CMS_CFG['list_num']]
 
     @staticmethod
     def count_of_certain_kind(kind):
@@ -879,10 +815,8 @@ class MPost(Mabc):
         Get the count of certain kind.
         '''
 
-        recs = TabPost.select().where(
-            (TabPost.kind == kind) &
-            (TabPost.valid == 1)
-        )
+        recs = TabPost.select().where((TabPost.kind == kind)
+                                      & (TabPost.valid == 1))
 
         return recs.count()
 
@@ -891,66 +825,49 @@ class MPost(Mabc):
         '''
         Return the number of certian slug.
         '''
-        return TabPost.select().where(
-            (TabPost.kind == kind) &
-            (TabPost.valid == 1)
-        ).count()
+        return TabPost.select().where((TabPost.kind == kind)
+                                      & (TabPost.valid == 1)).count()
 
     @staticmethod
     def query_pager_by_slug(kind, current_page_num=1):
         '''
         Query pager
         '''
-        return TabPost.select().where(
-            (TabPost.kind == kind) &
-            (TabPost.valid == 1)
-        ).order_by(
-            TabPost.time_create.desc()
-        ).paginate(
-            current_page_num, CMS_CFG['list_num']
-        )
-
+        return TabPost.select().where((TabPost.kind == kind)
+                                      & (TabPost.valid == 1)).order_by(
+            TabPost.time_create.desc()).paginate(
+            current_page_num,
+            CMS_CFG['list_num'])
 
     @staticmethod
-    def query_access(kind, day_sig, limit = 10):
+    def query_access(kind, day_sig, limit=10):
         '''
         返回最近几天访问的列表。
         day_sig为标识 : 'd' 为 近24小时， 'w'为近1击， 'm' 为近1月
         '''
         if day_sig == 'd':
-            return TabPost.select().where(
-                TabPost.kind == kind
-            ).order_by(
-                TabPost.access_1d.desc()
-            ).limit(limit)
+            return TabPost.select().where(TabPost.kind == kind).order_by(
+                TabPost.access_1d.desc()).limit(limit)
         elif day_sig == 'w':
-            return TabPost.select().where(
-                TabPost.kind == kind
-            ).order_by(
-                TabPost.access_7d.desc()
-            ).limit(limit)
+            return TabPost.select().where(TabPost.kind == kind).order_by(
+                TabPost.access_7d.desc()).limit(limit)
         elif day_sig == 'm':
-            return TabPost.select().where(
-                TabPost.kind == kind
-            ).order_by(
-                TabPost.access_30d.desc()
-            ).limit(limit)
+            return TabPost.select().where(TabPost.kind == kind).order_by(
+                TabPost.access_30d.desc()).limit(limit)
 
         return None
 
-
     @staticmethod
     def nullify(uid):
         '''
         使无效
         '''
 
-        entry = TabPost.update(
-            valid=0
-        ).where(TabPost.uid == uid)
+        entry = TabPost.update(valid=0).where(TabPost.uid == uid)
 
         try:
             entry.execute()
             return True
-        except:
+        except Exception as err:
+            print(repr(err))
             return False
