@@ -1,5 +1,4 @@
 # -*- coding:utf-8 -*-
-
 '''
 Basic configuration for CRUD.
 '''
@@ -19,8 +18,10 @@ for wfile in os.listdir(META_DIR):
         XLSX_FILE = os.path.join(META_DIR, wfile)
 
 # The filter key stored in the colomns below.
-RAW_LIST = ['E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N',
-            'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z']
+RAW_LIST = [
+    'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S',
+    'T', 'U', 'V', 'W', 'X', 'Y', 'Z'
+]
 
 FILTER_COLUMNS = RAW_LIST + ["A" + x for x in ['A', 'B', 'C', 'D'] + RAW_LIST] + \
                  ["B" + x for x in ['A', 'B', 'C', 'D'] + RAW_LIST] + \
